summaryrefslogtreecommitdiff
path: root/chart2/source/controller/inc/dlg_View3D.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'chart2/source/controller/inc/dlg_View3D.hxx')
-rw-r--r--chart2/source/controller/inc/dlg_View3D.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/chart2/source/controller/inc/dlg_View3D.hxx b/chart2/source/controller/inc/dlg_View3D.hxx
index d9e82e93000c..699916ff7b88 100644
--- a/chart2/source/controller/inc/dlg_View3D.hxx
+++ b/chart2/source/controller/inc/dlg_View3D.hxx
@@ -37,7 +37,7 @@
#include <vcl/tabctrl.hxx>
// header for class OKButton
#include <vcl/button.hxx>
// header for class XColorTable
#include <svx/xtable.hxx>
#include "ControllerLockGuard.hxx"
@@ -55,7 +55,7 @@ class View3DDialog : public TabDialog
public:
View3DDialog( Window* pWindow,
const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel > & xChartModel,
- XColorTable* pColorTable=0 );
+ XColorList* pColorTable=0 );
~View3DDialog();
// from Dialog (base of TabDialog)
@@ -37,7 +37,7 @@
// header for class OKButton
#include <vcl/button.hxx>
-// header for class XColorTable
+// header for class XColorList
#include <svx/xtable.hxx>
#include "ControllerLockGuard.hxx"